SharedString

Enum SharedString 

pub enum SharedString<'a> {
    Owned(Arc<Vec<u8>>),
    Borrowed(&'a [u8]),
    Sliced {
        other: Arc<Vec<u8>>,
        range: Range<usize>,
    },
}
Helper for holding either an owned or borrowed string, and where the slice method is aware of that borrowing, allowing for efficient copying and slicing without making extraneous additional copies

Variants



Owned(Arc<Vec<u8>>)



Borrowed(&'a [u8])



Sliced

Fields

other: Arc<Vec<u8>>
range: Range<usize>

Implementations

Source

impl SharedString<'_>

pub fn slice(&self, slice_range: Range<usize>) -> Self

pub fn as_bytes(&self) -> &[u8]

pub fn to_str(&self) -> Result<&str, Utf8Error>

pub fn to_str_lossy(&self) -> Cow<'_, str>

pub fn len(&self) -> usize

pub fn to_owned(&self) -> SharedString<'static>